<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method = "text" />
<xsl:template match="apache/serveroptions" xml:space="preserve"> 
#
# ServerRoot: The top of the directory tree under which the server's
# configuration, error, and log files are kept.
#
# NOTE!  If you intend to place this on an NFS (or otherwise network)
# mounted filesystem then please read the LockFile documentation
# (available at &lt;URL:http://httpd.apache.org/docs-2.0/mod/core.html#lockfile>);
# you will save yourself a lot of trouble.
#
# Do NOT add a slash at the end of the directory path.
#
ServerRoot "<xsl:value-of select="ServerRoot/@VALUE"/>"

#
# PidFile: The file in which the server should record its process
# identification number when it starts.
#
PidFile "<xsl:value-of select="PidFile/@VALUE"/>"

#
# Timeout: The number of seconds before receives and sends time out.
#
TimeOut <xsl:value-of select="TimeOut/@VALUE"/>

#
# KeepAlive: Whether or not to allow persistent connections (more than
# one request per connection). Set to "Off" to deactivate.
#
KeepAlive <xsl:value-of select="KeepAlive/@VALUE"/>

#
# MaxKeepAliveRequests: The maximum number of requests to allow
# during a persistent connection. Set to 0 to allow an unlimited amount.
# We recommend you leave this number high, for maximum performance.
#
MaxKeepAliveRequests <xsl:value-of select="MaxKeepAliveRequests/@VALUE"/>

#
# KeepAliveTimeout: Number of seconds to wait for the next request from the
# same client on the same connection.
#
KeepAliveTimeout <xsl:value-of select="KeepAliveTimeout/@VALUE"/>

##
## Server-Pool Size Regulation (MPM specific)
## 

# prefork MPM
# StartServers: number of server processes to start
# MinSpareServers: minimum number of server processes which are kept spare
# MaxSpareServers: maximum number of server processes which are kept spare
# MaxClients: maximum number of server processes allowed to start
# MaxRequestsPerChild: maximum number of requests a server process serves
&lt;IfModule prefork.c>
StartServers <xsl:value-of select="StartServers/@VALUE"/>
MinSpareServers <xsl:value-of select="MinSpareServers/@VALUE"/>
MaxSpareServers <xsl:value-of select="MaxSpareServers/@VALUE"/>
MaxClients <xsl:value-of select="MaxClients/@VALUE"/>
MaxRequestsPerChild <xsl:value-of select="MaxRequestsPerChild/@VALUE"/>
&lt;/IfModule>

#
# Listen: Allows you to bind Apache to specific IP addresses and/or
# ports, in addition to the default. See also the &lt;VirtualHost>
# directive.
#
# Change this to Listen on specific IP addresses as shown below to 
# prevent Apache from glomming onto all bound IP addresses (0.0.0.0)
#
#Listen 12.34.56.78:80
<xsl:for-each select="listener/Listen">Listen <xsl:value-of select="@VALUE" />
</xsl:for-each>

#
# User/Group: The name (or #number) of the user/group to run httpd as.
#  . On SCO (ODT 3) use "User nouser" and "Group nogroup".
#  . On HPUX you may not be able to use shared memory as nobody, and the
#    suggested workaround is to create a user www and use that user.
#  NOTE that some kernels refuse to setgid(Group) or semctl(IPC_SET)
#  when the value of (unsigned)Group is above 60000; 
#  don't use Group #-1 on these systems!
#
User <xsl:value-of select="User/@VALUE"/>
Group <xsl:value-of select="Group/@VALUE"/>

#
# ServerAdmin: Your address, where problems with the server should be
# e-mailed.  This address appears on some server-generated pages, such
# as error documents.  e.g. admin@your-domain.com
#
ServerAdmin <xsl:value-of select="ServerAdmin/@VALUE"/>

#
# ServerName gives the name and port that the server uses to identify itself.
# This can often be determined automatically, but we recommend you specify
# it explicitly to prevent problems during startup.
#
# If this is not set to valid DNS name for your host, server-generated
# redirections will not work.  See also the UseCanonicalName directive.
#
# If your host doesn't have a registered DNS name, enter its IP address here.
# You will have to access it by its address anyway, and this will make 
# redirections work in a sensible way.
#
ServerName <xsl:value-of select="ServerName/@VALUE"/>

#
# UseCanonicalName: Determines how Apache constructs self-referencing 
# URLs and the SERVER_NAME and SERVER_PORT variables.
# When set "Off", Apache will use the Hostname and Port supplied
# by the client.  When set "On", Apache will use the value of the
# ServerName directive.
#
UseCanonicalName <xsl:value-of select="UseCanonicalName/@VALUE"/>

#
# DocumentRoot: The directory out of which you will serve your
# documents. By default, all requests are taken from this directory, but
# symbolic links and aliases may be used to point to other locations.
#
DocumentRoot "<xsl:value-of select="DocumentRoot/@VALUE"/>"

#
# UserDir: The name of the directory that is appended onto a user's home
# directory if a ~user request is received.
#
# The path to the end user account 'public_html' directory must be
# accessible to the webserver userid.  This usually means that ~userid
# must have permissions of 711, ~userid/public_html must have permissions
# of 755, and documents contained therein must be world-readable.
# Otherwise, the client will only receive a "403 Forbidden" message.
#
# See also: http://httpd.apache.org/docs/misc/FAQ.html#forbidden
#
&lt;IfModule mod_userdir.c>
    #
    # UserDir is disabled by default since it can confirm the presence
    # of a username on the system (depending on home directory
    # permissions).
    #
    UserDir "<xsl:value-of select="UserDir/@VALUE"/>"

    #
    # To enable requests to /~user/ to serve the user's public_html
    # directory, use this directive instead of "UserDir disable":
    # 
    #UserDir public_html

&lt;/IfModule>

#
# DirectoryIndex: sets the file that Apache will serve if a directory
# is requested.
#
# The index.html.var file (a type-map) is used to deliver content-
# negotiated documents.  The MultiViews Option can be used for the 
# same purpose, but it is much slower.
#
DirectoryIndex <xsl:value-of select="DirectoryIndex/@VALUE"/>

#
# AccessFileName: The name of the file to look for in each directory
# for access control information.  See also the AllowOverride directive.
#
AccessFileName <xsl:value-of select="AccessFileName/@VALUE"/>

#
# TypesConfig describes where the mime.types file (or equivalent) is
# to be found.
#
TypesConfig "<xsl:value-of select="TypesConfig/@VALUE"/>"

#
# DefaultType is the default MIME type the server will use for a document
# if it cannot otherwise determine one, such as from filename extensions.
# If your server contains mostly text or HTML documents, "text/plain" is
# a good value.  If most of your content is binary, such as applications
# or images, you may want to use "application/octet-stream" instead to
# keep browsers from trying to display binary files as though they are
# text.
#
DefaultType <xsl:value-of select="DefaultType/@VALUE"/>

#
# HostnameLookups: Log the names of clients or just their IP addresses
# e.g., www.apache.org (on) or 204.62.129.132 (off).
# The default is off because it'd be overall better for the net if people
# had to knowingly turn this feature on, since enabling it means that
# each client request will result in AT LEAST one lookup request to the
# nameserver.
#
HostNameLookups <xsl:value-of select="HostNameLookups/@VALUE"/>

#
# ErrorLog: The location of the error log file.
# If you do not specify an ErrorLog directive within a &lt;VirtualHost>
# container, error messages relating to that virtual host will be
# logged here.  If you *do* define an error logfile for a &lt;VirtualHost>
# container, that host's errors will be logged there and not here.
#
ErrorLog "<xsl:value-of select="ErrorLog/@VALUE"/>"

#
# LogLevel: Control the number of messages logged to the error_log.
# Possible values include: debug, info, notice, warn, error, crit,
# alert, emerg.
#
LogLevel <xsl:value-of select="LogLevel/@VALUE"/>

#
# The following directives define some format nicknames for use with
# a CustomLog directive (see below).
#
<xsl:for-each select="LogFormat">LogFormat "<xsl:value-of select="@VALUE" />"
</xsl:for-each>

#
# Optionally add a line containing the server version and virtual host
# name to server-generated pages (error documents, FTP directory listings,
# mod_status and mod_info output etc., but not CGI generated documents).
# Set to "EMail" to also include a mailto: link to the ServerAdmin.
# Set to one of:  On | Off | EMail
#
ServerSignature <xsl:value-of select="ServerSignature/@VALUE"/>

#
# FancyIndexing is whether you want fancy directory indexing or standard.
# VersionSort is whether files containing version numbers should be 
# compared in the natural way, so that `apache-1.3.9.tar' is placed before
# `apache-1.3.12.tar'.
#
IndexOptions <xsl:value-of select="IndexOptions/@VALUE"/>

#
# Customizable error responses come in three flavors:
# 1) plain text 2) local redirects 3) external redirects
#
# Some examples:
#ErrorDocument 500 "The server made a boo boo."
#ErrorDocument 404 /missing.html
#ErrorDocument 404 "/cgi-bin/missing_handler.pl"
#ErrorDocument 402 http://www.example.com/subscription_info.html
#
<xsl:for-each select="errordocuments/errordocument">ErrorDocument <xsl:value-of select="Code/@VALUE"/> "<xsl:value-of select="Document//@VALUE"/>" 
</xsl:for-each>

#
# Use name-based virtual hosting.
#
<xsl:for-each select="namevirtualhosts/NameVirtualHost">NameVirtualHost <xsl:value-of select="@VALUE" />
</xsl:for-each>

# Where do we put the lock and pif files?
LockFile "<xsl:value-of select="LockFile/@VALUE"/>"
CoreDumpDirectory "<xsl:value-of select="CoreDumpDirectory/@VALUE"/>"

# Defaults for virtual hosts
<xsl:for-each select="SSLCertificateFile">SSLCertificateFile <xsl:value-of select="@VALUE" /></xsl:for-each>
<xsl:for-each select="SSLCertificateKeyFile">SSLCertificateKeyFile <xsl:value-of select="@VALUE" /></xsl:for-each>
<xsl:for-each select="SSLCertificateChainFile">SSLCertificateChainFile <xsl:value-of select="@VALUE" /></xsl:for-each>
<xsl:for-each select="SSLCACertificatePath">SSLCACertificatePath <xsl:value-of select="@VALUE" /></xsl:for-each>

# Logs
<xsl:for-each select="TransferLog">TransferLog <xsl:value-of select="@VALUE" /></xsl:for-each>

</xsl:template>

<xsl:template match="apache/virtualhosts" xml:space="preserve"> 
#
# Virtual hosts
#
<xsl:for-each select="virtualhost">
# Virtual host <xsl:value-of select="VHName/@VALUE" />
<xsl:text disable-output-escaping="yes">&lt;</xsl:text>VirtualHost <xsl:for-each select="Address"><xsl:value-of select="@VALUE" /></xsl:for-each>&gt;
 	<xsl:for-each select="DocumentRoot">DocumentRoot <xsl:value-of select="@VALUE" /> </xsl:for-each>
 	<xsl:for-each select="ErrorLog">ErrorLog <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="ServerAdmin">ServerAdmin <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="ServerName"><xsl:if test="not(@VALUE = '_default_')">ServerName <xsl:value-of select="@VALUE"/></xsl:if>
	</xsl:for-each>
<xsl:for-each select="serveraliases/ServerAlias">
        ServerAlias <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="ServerSignature">ServerSignature <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="TransferLog">TransferLog <xsl:value-of select="@VALUE" /></xsl:for-each>
	<xsl:for-each select="DirectoryIndex">DirectoryIndex <xsl:value-of select="@VALUE" /> </xsl:for-each>
	<xsl:for-each select="directories/directory">
	<xsl:text disable-output-escaping="yes">&lt;</xsl:text>Directory "<xsl:for-each select="Dir"><xsl:value-of select="@VALUE" /></xsl:for-each>"&gt;
		<xsl:for-each select="Options">Options <xsl:value-of select="@VALUE" />
		</xsl:for-each>
	 	<xsl:for-each select="AllowOverride">AllowOverride <xsl:value-of select="@VALUE" /></xsl:for-each>
 		<xsl:for-each select="Allow">Allow from <xsl:value-of select="@VALUE" /></xsl:for-each>
		<xsl:for-each select="Deny">Deny from <xsl:value-of select="@VALUE" /></xsl:for-each>
		<xsl:for-each select="Order">Order <xsl:value-of select="@VALUE" /></xsl:for-each>
	<xsl:text disable-output-escaping="yes">&lt;</xsl:text>/Directory&gt; 
	</xsl:for-each>
	<xsl:for-each select="errordocuments/errordocument">ErrorDocument <xsl:value-of select="Code/@VALUE"/> "<xsl:value-of select="Document/@VALUE"/>"
	</xsl:for-each>
 	<xsl:for-each select="SSLEngine">SSLEngine <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="SSLCertificateFile">SSLCertificateFile <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="SSLCertificateKeyFile">SSLCertificateKeyFile <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="SSLCertificateChainFile">SSLCertificateChainFile <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="SSLCACertificateFile">SSLCACertificateFile <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="SSLCACertificatePath">SSLCACertificatePath <xsl:value-of select="@VALUE" /></xsl:for-each>
        <xsl:for-each select="SSLOptions">SSLOptions <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="LogFormat">LogFormat "<xsl:value-of select="@VALUE" />"</xsl:for-each>
 	<xsl:for-each select="TransferLog">TransferLog <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="ErrorLog">ErrorLog <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="LogLevel">LogLevel <xsl:value-of select="@VALUE" /></xsl:for-each>
 	<xsl:for-each select="HostNameLookups">HostNameLookups <xsl:value-of select="@VALUE" /></xsl:for-each>
	<xsl:for-each select="environment/env[EnvType/@VALUE='pass']">PassEnv "<xsl:value-of select="Var/@VALUE" />"
	</xsl:for-each>
	<xsl:for-each select="environment/env[EnvType/@VALUE='unset']">UnsetEnv "<xsl:value-of select="Var/@VALUE" />"
	</xsl:for-each>
	<xsl:for-each select="environment/env[EnvType/@VALUE='set']">SetEnv "<xsl:value-of select="Var/@VALUE" />" "<xsl:value-of select="Value/@VALUE" />"
	</xsl:for-each>

<xsl:text disable-output-escaping="yes">&lt;</xsl:text>/VirtualHost&gt;
</xsl:for-each>
</xsl:template>

<xsl:template match="apache/directories" xml:space="preserve">
#
# Each directory to which Apache has access can be configured with respect
# to which services and features are allowed and/or disabled in that
# directory (and its subdirectories). 
#
# Note that from this point forward you must specifically allow
# particular features to be enabled - so if something's not working as
# you might expect, make sure that you have specifically enabled it
# below.
#
<xsl:for-each select="directory">
<xsl:text disable-output-escaping="yes">&lt;</xsl:text>Directory "<xsl:for-each select="Dir"><xsl:value-of select="@VALUE" /></xsl:for-each>"&gt;
        <xsl:for-each select="Options">Options <xsl:value-of select="@VALUE" />
        </xsl:for-each>
        <xsl:for-each select="AllowOverride">AllowOverride <xsl:value-of select="@VALUE" /></xsl:for-each>
        <xsl:for-each select="Allow">Allow from <xsl:value-of select="@VALUE" />
</xsl:for-each>
        <xsl:for-each select="Deny">Deny from <xsl:value-of select="@VALUE" />
</xsl:for-each>
        <xsl:for-each select="Order">Order <xsl:value-of select="@VALUE" /></xsl:for-each>
<xsl:text disable-output-escaping="yes">&lt;</xsl:text>/Directory&gt;
</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
